@@ -8,7 +8,7 @@
 
 #define END_OF_VEC -1
 
-int nadd;
+//int nadd;
 double thresholdtorev;
 int dodp;
 int addfragment;
